import setuptools

# Reads the content of your README.md into a variable to be used in the setup below
with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="ml_framework",  # name of the package
    packages=setuptools.find_packages(),  # import all available packages
    version="0.0.20",  # version tag
    license="MIT",  # package license
    description="Machine Learning Framework",
    long_description=long_description,  # loads your README.md
    long_description_content_type="text/markdown",  # README.md is of type 'markdown'
    author="feketedavid1012&ansticky",  # displayed name of the authors
    author_email="antsticky@gmail.com",  # contact email address
    url="https://github.com/antsticky/AILib/",
    project_urls={"Bug Tracker": "https://github.com/antsticky/AILib//issues"},
    install_requires=["requests"],  # list of all packages that are used
    keywords=["framework", "ML", "AI"],  # descriptive meta-data
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Documentation",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
    ],
    download_url="https://github.com/antsticky/AILib/archive/refs/tags/0.0.3.tar.gz",
)
